DropItem<T> class

Constructors

DropItem({required int id, int? index, required String name, String? flag, T? data})
DropItem.fromJson(Map<String, dynamic> json)
factory

Properties

data ↔ T?
getter/setter pair
flag String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int
getter/setter pair
index int?
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? nameSelected, int? id, int? index}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override