AutoDropButtonStyle class

Constructors

AutoDropButtonStyle({List<BoxShadow>? boxShadow = const [BoxShadow(color: Color(0xFFCDE2FE), blurRadius: 3, offset: Offset(0, 1))], Border? border, MainAxisAlignment? mainAxisAlignment, Color backgroundColor = Colors.white, Color primaryColor = Colors.black87, BoxConstraints? constraints, double height = 50, double radius = 8.0, double? width, double elevation = 1, EdgeInsets padding = EdgeInsets.zero, ShapeBorder? shape})
const

Properties

backgroundColor Color
final
border Border?
final
boxShadow List<BoxShadow>?
final
constraints BoxConstraints?
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
mainAxisAlignment MainAxisAlignment?
final
padding EdgeInsets
final
primaryColor Color
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape ShapeBorder?
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited