AutoDropStyle class

Constructors

AutoDropStyle({BoxConstraints? constraints, Offset? offset, double? width, double elevation = 10, ShapeBorder? shape, Color? color, EdgeInsets? padding, Color? scrollbarColor})
const

Properties

color Color?
final
constraints BoxConstraints?
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
offset Offset?
position of the top left of the dropdown relative to the top left of the button
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarColor Color?
final
shape ShapeBorder?
Add shape and border radius of the dropdown from here
final
width double?
button width must be set for this to take effect
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited