TextDropStyle class
Constructors
- TextDropStyle({int? maxLines, TextOverflow overflow = TextOverflow.ellipsis, FontWeight fontWeight = FontWeight.w500, double fontSize = 14, Color? textColor})
-
const
Properties
- fontSize → double
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int?
-
final
- overflow → TextOverflow
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited